==> pegasus-merchandise-api-1.4.29-sources.jar: com/thebeastshop/pegasus/merchandise/vo/PcsBuyerInfoVO.java <==
package com.thebeastshop.pegasus.merchandise.vo;


import java.io.Serializable;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import com.thebeastshop.pegasus.util.comm.EmptyUtil;

/**
 * Created by devin.li on 2016/2/13.
 */
public class PcsBuyerInfoVO implements Serializable{
	
	/**
	 * 
	 */
	private static final long serialVersionUID = 2351217463747450801L;

	final public static Integer DISABLE_YES = 1;

	final public static Integer DISABLE_NO = 0;


	private Long id;

	private String nickName;

	private String realName;

	private Date createTime;

	private Integer createUserId;

	private String memo;

	private Integer loginUserId;

	private String viewPermissions;

	private Integer categoryManager;

	private String loginName;
	
	private String categoryManagerName;
	
	private List<Long> userIds;
	
	private List<String> loginNames;
	
	private List<UserVO> users;
	
	//商业品类
	private List<String> categoryList;
	
	//采购品类
	private List<String> purchaseCategoryList;
	
	private Integer operate;
	
	private String bussinessCategory;
	    
    private String purchaseCategory;

	//采购员状态
	private Integer disable;

	private Integer skuAmount;
	    
	
    
    

	public String getBussinessCategory() {
		return bussinessCategory;
	}

	public void setBussinessCategory(String bussinessCategory) {
		/*if(EmptyUtil.isNotEmpty(categoryList)) {
			for(int i = 0; i < categoryList.size(); i ++) {
				if(i == 0) {
					bussinessCategory += categoryList.get(i);
				} else {
					bussinessCategory += "," + categoryList.get(i);
				}
			}
		}*/
		this.bussinessCategory = bussinessCategory;
	}

	public String getPurchaseCategory() {
		return purchaseCategory;
	}

	public void setPurchaseCategory(String purchaseCategory) {
		/*f(EmptyUtil.isNotEmpty(purchaseCategoryList)) {
			for(int i = 0; i < purchaseCategoryList.size(); i ++) {
				if(i == 0) {
					purchaseCategory += purchaseCategoryList.get(i);
				} else {
					purchaseCategory += "," + purchaseCategoryList.get(i);
				}
			}
		}*/
		this.purchaseCategory = purchaseCategory;
	}

	public Integer getOperate() {
		return operate;
	}

	public void setOperate(Integer operate) {
		this.operate = operate;
	}

	public List<String> getCategoryList() {
		/*categoryList = new ArrayList<>();
		if(EmptyUtil.isNotEmpty(this.bussinessCategory)) {
			String[] array = this.bussinessCategory.split(",");
			for(String categoryId : array) {
				categoryList.add(categoryId);
			}
		}*/
		return categoryList;
	}

	public void setCategoryList(List<String> categoryList) {
		this.categoryList = categoryList;
	}

	public List<String> getPurchaseCategoryList() {
		/*purchaseCategoryList = new ArrayList<>();
		if(EmptyUtil.isNotEmpty(this.purchaseCategory)) {
			String[] array = this.purchaseCategory.split(",");
			for(String categoryId : array) {
				purchaseCategoryList.add(categoryId);
			}
		}*/
		return purchaseCategoryList;
	}

	public void setPurchaseCategoryList(List<String> purchaseCategoryList) {
		this.purchaseCategoryList = purchaseCategoryList;
	}

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public String getNickName() {
		return nickName;
	}

	public void setNickName(String nickName) {
		this.nickName = nickName;
	}

	public String getRealName() {
		return realName;
	}

	public void setRealName(String realName) {
		this.realName = realName;
	}

	public Date getCreateTime() {
		return createTime;
	}

	public void setCreateTime(Date createTime) {
		this.createTime = createTime;
	}

	public Integer getCreateUserId() {
		return createUserId;
	}

	public void setCreateUserId(Integer createUserId) {
		this.createUserId = createUserId;
	}

	public String getMemo() {
		return memo;
	}

	public void setMemo(String memo) {
		this.memo = memo;
	}

	public Integer getLoginUserId() {
		return loginUserId;
	}

	public void setLoginUserId(Integer loginUserId) {
		this.loginUserId = loginUserId;
	}

	public String getViewPermissions() {
		return viewPermissions;
	}

	public void setViewPermissions(String viewPermissions) {
		this.viewPermissions = viewPermissions;
	}

	public Integer getCategoryManager() {
		return categoryManager;
	}

	public void setCategoryManager(Integer categoryManager) {
		this.categoryManager = categoryManager;
	}

	public String getCategoryManagerName() {
		return categoryManagerName;
	}

	public void setCategoryManagerName(String categoryManagerName) {
		this.categoryManagerName = categoryManagerName;
	}

	public List<UserVO> getUsers() {
		return users;
	}

	public void setUsers(List<UserVO> users) {
		this.users = users;
	}

	public String getLoginName() {
		return loginName;
	}

	public void setLoginName(String loginName) {
		this.loginName = loginName;
	}

	
	public List<Long> getUserIds() {
		return userIds;
	}

	public void setUserIds(List<Long> userIds) {
		this.userIds = userIds;
	}

	public Integer getDisable() {
		return disable;
	}

	public void setDisable(Integer disable) {
		this.disable = disable;
	}

	public Integer getSkuAmount() {
		return skuAmount;
	}

	public void setSkuAmount(Integer skuAmount) {
		this.skuAmount = skuAmount;
	}

	public List<String> getLoginNames() {
		return loginNames;
	}

	public void setLoginNames(List<String> loginNames) {
		this.loginNames = loginNames;
	}
	
	
	
}

==> pegasus-merchandise-api-1.6.3-sources.jar: com/thebeastshop/pegasus/merchandise/vo/PcsBuyerInfoVO.java <==
package com.thebeastshop.pegasus.merchandise.vo;


import java.io.Serializable;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import com.thebeastshop.pegasus.util.comm.EmptyUtil;

/**
 * Created by devin.li on 2016/2/13.
 */
public class PcsBuyerInfoVO implements Serializable{
	
	/**
	 * 
	 */
	private static final long serialVersionUID = 2351217463747450801L;

	final public static Integer DISABLE_YES = 1;

	final public static Integer DISABLE_NO = 0;


	private Long id;

	private String nickName;

	private String realName;

	private Date createTime;

	private Integer createUserId;

	private String memo;

	private Integer loginUserId;

	private String viewPermissions;

	private Integer categoryManager;

	private String loginName;
	
	private String categoryManagerName;
	
	private List<Long> userIds;
	
	private List<String> loginNames;
	
	private List<UserVO> users;
	
	//商业品类
	private List<String> categoryList;
	
	//采购品类
	private List<String> purchaseCategoryList;
	
	private Integer operate;
	
	private String bussinessCategory;
	    
    private String purchaseCategory;

	//采购员状态
	private Integer disable;

	private Integer skuAmount;

	private String emailAddress;

	public String getBussinessCategory() {
		return bussinessCategory;
	}

	public void setBussinessCategory(String bussinessCategory) {
		/*if(EmptyUtil.isNotEmpty(categoryList)) {
			for(int i = 0; i < categoryList.size(); i ++) {
				if(i == 0) {
					bussinessCategory += categoryList.get(i);
				} else {
					bussinessCategory += "," + categoryList.get(i);
				}
			}
		}*/
		this.bussinessCategory = bussinessCategory;
	}

	public String getPurchaseCategory() {
		return purchaseCategory;
	}

	public void setPurchaseCategory(String purchaseCategory) {
		/*f(EmptyUtil.isNotEmpty(purchaseCategoryList)) {
			for(int i = 0; i < purchaseCategoryList.size(); i ++) {
				if(i == 0) {
					purchaseCategory += purchaseCategoryList.get(i);
				} else {
					purchaseCategory += "," + purchaseCategoryList.get(i);
				}
			}
		}*/
		this.purchaseCategory = purchaseCategory;
	}

	public Integer getOperate() {
		return operate;
	}

	public void setOperate(Integer operate) {
		this.operate = operate;
	}

	public List<String> getCategoryList() {
		/*categoryList = new ArrayList<>();
		if(EmptyUtil.isNotEmpty(this.bussinessCategory)) {
			String[] array = this.bussinessCategory.split(",");
			for(String categoryId : array) {
				categoryList.add(categoryId);
			}
		}*/
		return categoryList;
	}

	public void setCategoryList(List<String> categoryList) {
		this.categoryList = categoryList;
	}

	public List<String> getPurchaseCategoryList() {
		/*purchaseCategoryList = new ArrayList<>();
		if(EmptyUtil.isNotEmpty(this.purchaseCategory)) {
			String[] array = this.purchaseCategory.split(",");
			for(String categoryId : array) {
				purchaseCategoryList.add(categoryId);
			}
		}*/
		return purchaseCategoryList;
	}

	public void setPurchaseCategoryList(List<String> purchaseCategoryList) {
		this.purchaseCategoryList = purchaseCategoryList;
	}

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public String getNickName() {
		return nickName;
	}

	public void setNickName(String nickName) {
		this.nickName = nickName;
	}

	public String getRealName() {
		return realName;
	}

	public void setRealName(String realName) {
		this.realName = realName;
	}

	public Date getCreateTime() {
		return createTime;
	}

	public void setCreateTime(Date createTime) {
		this.createTime = createTime;
	}

	public Integer getCreateUserId() {
		return createUserId;
	}

	public void setCreateUserId(Integer createUserId) {
		this.createUserId = createUserId;
	}

	public String getMemo() {
		return memo;
	}

	public void setMemo(String memo) {
		this.memo = memo;
	}

	public Integer getLoginUserId() {
		return loginUserId;
	}

	public void setLoginUserId(Integer loginUserId) {
		this.loginUserId = loginUserId;
	}

	public String getViewPermissions() {
		return viewPermissions;
	}

	public void setViewPermissions(String viewPermissions) {
		this.viewPermissions = viewPermissions;
	}

	public Integer getCategoryManager() {
		return categoryManager;
	}

	public void setCategoryManager(Integer categoryManager) {
		this.categoryManager = categoryManager;
	}

	public String getCategoryManagerName() {
		return categoryManagerName;
	}

	public void setCategoryManagerName(String categoryManagerName) {
		this.categoryManagerName = categoryManagerName;
	}

	public List<UserVO> getUsers() {
		return users;
	}

	public void setUsers(List<UserVO> users) {
		this.users = users;
	}

	public String getLoginName() {
		return loginName;
	}

	public void setLoginName(String loginName) {
		this.loginName = loginName;
	}

	
	public List<Long> getUserIds() {
		return userIds;
	}

	public void setUserIds(List<Long> userIds) {
		this.userIds = userIds;
	}

	public Integer getDisable() {
		return disable;
	}

	public void setDisable(Integer disable) {
		this.disable = disable;
	}

	public Integer getSkuAmount() {
		return skuAmount;
	}

	public void setSkuAmount(Integer skuAmount) {
		this.skuAmount = skuAmount;
	}

    public String getEmailAddress() {
        return emailAddress;
    }

    public void setEmailAddress(String emailAddress) {
        this.emailAddress = emailAddress;
    }

    public List<String> getLoginNames() {
		return loginNames;
	}

	public void setLoginNames(List<String> loginNames) {
		this.loginNames = loginNames;
	}
	
	
	
}
